pub struct PackageState {
pub protected: BTreeSet<PackageName>,
pub pubkeys: BTreeMap<String, PublicKeyFile>,
pub installed: BTreeMap<PackageName, InstallState>,
}Expand description
Contains current user packages state
Fields
protected: BTreeSet<PackageName>list of can’t be accidentally uninstalled packages
pubkeys: BTreeMap<String, PublicKeyFile>installed public keys per remote name. using pkgar_keys as a wrapper of dryoc public key.
installed: BTreeMap<PackageName, InstallState>install state per packages
Implementations
Sourceimpl PackageState
impl PackageState
pub fn from_toml(text: &str) -> Result<Self, Error>
pub fn to_toml(&self) -> String
Sourcepub fn install(&mut self, packages: &[RemotePackage]) -> Vec<PackageName>
pub fn install(&mut self, packages: &[RemotePackage]) -> Vec<PackageName>
Returns list of packages that need to be resolved, which are not yet added to the package config. If zero vector returned, it means all package deps are satisfied
Sourcepub fn uninstall(&mut self, packages: &[PackageName]) -> Vec<PackageName>
pub fn uninstall(&mut self, packages: &[PackageName]) -> Vec<PackageName>
Returns list of packages that also need to be resolved, which are not all of their deps is listed in list of packages. If zero vector returned, it means uninstallation can be executed.
pub fn diff(&self, newer: &Self) -> PackageList
pub fn get_installed_list(&self) -> Vec<PackageName>
Sourcepub fn mark_as_manual(
&mut self,
manual: bool,
packages: &[PackageName],
) -> Vec<PackageName>
pub fn mark_as_manual( &mut self, manual: bool, packages: &[PackageName], ) -> Vec<PackageName>
Mark packages manually installed or not. Returns list of changed packages. PackageState are not marked automatically in any install mechanism.